pub struct Error {
pub code: ErrorCode,
pub message: String,
pub data: Option<Value>,
}Expand description
JSON-RPC Error Object.
Fields
code: ErrorCodeA Number that indicates the error type that occurred. This MUST be an integer.
message: StringA String providing a short description of the error. The message SHOULD be limited to a concise single sentence.
data: Option<Value>A Primitive or Structured value that contains additional information about the error. This may be omitted. The value of this member is defined by the Server (e.g. detailed error information, nested errors etc.).
Implementations
Sourceimpl Error
impl Error
Sourcepub fn parse_error() -> Self
pub fn parse_error() -> Self
Creates a new ParseError error.
Sourcepub fn invalid_request() -> Self
pub fn invalid_request() -> Self
Creates a new InvalidRequest error.
Sourcepub fn method_not_found() -> Self
pub fn method_not_found() -> Self
Creates a new MethodNotFound error.
Sourcepub fn invalid_params<M>(message: M) -> Selfwhere
M: Display,
pub fn invalid_params<M>(message: M) -> Selfwhere
M: Display,
Creates a new InvalidParams error with given message.
Sourcepub fn invalid_params_with_details<M, D>(message: M, details: D) -> Self
pub fn invalid_params_with_details<M, D>(message: M, details: D) -> Self
Creates a new InvalidParams error with given message and details.
Sourcepub fn internal_error() -> Self
pub fn internal_error() -> Self
Creates a new InternalError error.
Sourcepub fn invalid_version() -> Self
pub fn invalid_version() -> Self
Creates a new InvalidRequest error with invalid version description.