pub struct Notification {
pub method: String,
pub params: Params,
}Expand description
Represents JSON-RPC 1.0 request which is a notification.
A Request object that is a Notification signifies the Client’s lack of interest in the corresponding Response object, and as such no Response object needs to be returned to the client. As such, the Client would not be aware of any errors (like e.g. “Invalid params”,“Internal error”).
The Server MUST NOT reply to a Notification, including those that are within a batch request.
For JSON-RPC 1.0 specification, notification id MUST be Null.
Fields
method: StringA String containing the name of the method to be invoked.
Method names that begin with the word rpc followed by a period character (U+002E or ASCII 46) are reserved for rpc-internal methods and extensions and MUST NOT be used for anything else.
params: ParamsA Structured value that holds the parameter values to be used during the invocation of the method.
Implementations